Crate parity_publish_semver_checks

Crate parity_publish_semver_checks 

Structs

Check
Test a release for semver violations.
CrateReport
Report of semver check of one crate.
GlobalConfig
OverrideStack
Stores a stack of OverrideMap references such that items towards the top of the stack (later in the backing Vec) have higher precedence and override items lower in the stack. That is, when an override is set and not None for a given lint in multiple maps in the stack, the value at the top of the stack will be used to calculate the effective lint level or required version update.
PackageSelection
QueryOverride
Configured values for a SemverQuery that differ from the lint’s defaults.
Report
Report of the whole analysis. Contains a report for each crate checked.
Rustdoc
SemverQuery
A query that can be executed on a pair of rustdoc output files, returning instances of a particular kind of semver violation.

Enums

ActualSemverUpdate
Kind of semver update.
LintLevel
The level of intensity of the error when a lint occurs.
ReleaseType
The kind of release we’re making.
RequiredSemverUpdate
ScopeSelection

Type Aliases

OverrideMap
A mapping of lint ids to configured values that override that lint’s defaults.