Stores a stack of OverrideMap references such that items towards the top of
the stack (later in the backing Vec) have higher precedence and override items lower in the stack.
That is, when an override is set and not None for a given lint in multiple maps in the stack, the value
at the top of the stack will be used to calculate the effective lint level or required version update.